@@ -7,7 +7,7 @@ from tqdm.auto import tqdm
 from sentence_splitter import SentenceSplitter, split_text_into_sentences
 from .diff import dff_text
 from .text_tilling import auto_text_tilling
-
+from .cut import auto_cut_markdown
 def get_markdown_images(text):
     """
     从markdown中提取图片
@@ -631,59 +631,31 @@ class AutoReWrite(object):
         :param text:  # 输入的文本内容，不限制字数
         :return new:  返回生成句子列表
         """
-        splitter = SentenceSplitter(language='en')
-        # print(splitter.split(text='This is a paragraph. It contains several sentences. "But why," you ask?'))
-        # ['This is a paragraph.', 'It contains several sentences.', '"But why," you ask?']
-        # ["del summary paraphrase：", "del：", "summary：", "paraphrase：", "del summary paraphrase："]
+
 
         newdata = []
-        images_list = []
-
-        # for p in text.split('\n'):
         # 自动拆分段落，并且对文本中的图像进行分割为单独段落。
-        ps,imgs=get_markdown_images_format(text)
-        p_list=[]
-        for p_text,images in tqdm(zip(ps,imgs)):
-
-            # 拼接段落，防止出现过短的段落出现
-            p_list.append(p_text)
-            if len("\n".join(p_list).split(" "))>128:
-                p="\n".join(p_list)
-                p_list=[]
-            else:
-                continue
-
-            # 判断是否存在图片，如果存在图片则不做重写
-            # images = get_markdown_images(p)
-            if images is None and len(p)>0 and p is not None:
-                # print("p===================\n",p)
-
-
+        for item in tqdm(auto_cut_markdown(text)):
+            if len(item['text'])>0:
                 try:
-                    out=self.auto_summary(p,auto_sample=True,temperature=temperature)
+                    out=self.auto_summary(item['text'],auto_sample=True,temperature=temperature)
                 except Exception as e:
+
                     pass
                 # print(out)
                 try:
                     if out.get("results") and type(out)==dict and out['results'][0][0]['summary_text'] is not None:
 
-                        newdata.append(out['results'][0][0]['summary_text'])
-                    # else:
-                    #     newdata.append(p)
+                        item["results"]=out['results'][0][0]['summary_text']
                 except Exception as e:
                     if type(out)==dict and out['results'][0][0][0]['summary_text'] is not None:
 
-                        newdata.append(out['results'][0][0][0]['summary_text'])
+                        item["results"]=out['results'][0][0][0]['summary_text']
 
-                    else:
-                        newdata.append(p)
-            else:
-                newdata.append(p)
-                images_list.append(images)
-            newdata.append("\n")
-        # print(text, "\n")
-        # print("".join(new), "\n")
-        return {"items": newdata, "images": images_list}
+            yield item
+        #     newdata.append(item)
+
+        # return newdata
 
 
 def rewriter_by_summary(text,auto_sample=False,simlimit=0.6,temperature=1.2,api='http://192.168.1.18:3011',api_sbert_host="http://192.168.1.18:3016",**kwargs):
@@ -692,17 +664,17 @@ def rewriter_by_summary(text,auto_sample=False,simlimit=0.6,temperature=1.2,api=
 
     """
     # 自动分段处理
-    text= auto_text_tilling(text)
-    rewriter = AutoReWrite(api='http://192.168.1.18:3011',api_sbert_host="http://192.168.1.18:3016")
-
+    # text= auto_text_tilling(text)
+    rewriter = AutoReWrite(api=api,api_sbert_host=api_sbert_host)
     # for temperature in [1.2]:
     out = rewriter.rewriter_by_summary(text, simlimit=0.6, simlimitmax=0.999999999, auto_sample=False,temperature=temperature)
 
-    text="\n ".join(out['items'])
-    text= auto_text_tilling(text)
-    # 提取图片信息
-    text_list,images=get_markdown_images_format(text)
-    return text_list,images
+    # text="\n ".join(out['items'])
+    # text= auto_text_tilling(text)
+    # # 提取图片信息
+    # text_list,images=get_markdown_images_format(text)
+    # return text_list,images
+    return out
 
 if __name__ == "__main__":
     # payload = {"config": {
